@@ -16,10 +16,13 @@ def register():
         PartyCategory,
         PartyIdentifier,
         CheckVIESResult,
+        PartyReplaceAsk,
         Address,
+        AddressFormat,
         ContactMechanism,
         Configuration,
         module='party', type_='model')
     Pool.register(
         CheckVIES,
+        PartyReplace,
         module='party', type_='wizard')
