@@ -4,7 +4,7 @@
 from string import Template
 
 from sql import Null
-from sql.conditionals import Case
+from sql.conditionals import Case, Coalesce
 from sql.operators import Concat
 
 from trytond.model import ModelView, ModelSQL, MatchMixin, fields, \
@@ -69,7 +69,9 @@ class Address(sequence_ordered(), ModelSQL, ModelView):
 
         # Migration from 4.0: remove streetbis
         if table.column_exist('streetbis'):
-            value = Concat(sql_table.street, Concat('\n', sql_table.streetbis))
+            value = Concat(
+                Coalesce(sql_table.street, ''),
+                Concat('\n', Coalesce(sql_table.streetbis, '')))
             cursor.execute(*sql_table.update(
                     [sql_table.street],
                     [value]))
@@ -138,6 +140,11 @@ class Address(sequence_ordered(), ModelSQL, ModelView):
             'country': self.country.name if self.country else '',
             'country_code': self.country.code if self.country else '',
             }
+
+        # Map invalid substitutions district* to subdivision* on 4.2.
+        substitutions['district'] = substitutions['subdivision']
+        substitutions['district_code'] = substitutions['subdivision_code']
+
         if context.get('address_from_country') == self.country:
             substitutions['country'] = ''
         if context.get('address_with_party', False):
